/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_BUDGETING_CONSTANTS_HPP_
#define DRN_BUDGETING_CONSTANTS_HPP_

/**
 * @file Constant.hpp This is a collection of numerical and C-style string constants. This must not
 * include any declaration files.
 */

namespace drn::budgeting
{

/// The constant that contains the minimum number of possible hours in a standard calendar week.
constexpr int minimumHoursInAWeek{1};
/// The constant that contains the minimum number of possible days in a standard calendar week.
constexpr int minimumDaysInAWeek{1};
/// The constant that contains the total number of possible hours in a standard calendar week.
constexpr int maximumHoursInAWeek{168};
/// The constant that contains the total number of possible days in a standard calendar week.
constexpr int maximumDaysInAWeek{7};
/// The constant that contains the minimum number of days to notify when a budget item is due.
constexpr int minimumDaysNotifyWithin{0};
/// The constant that contains the maximum number of days to notify when a budget item is due.
constexpr int maximumDaysNotifyWithin{60};
/// The constant that contains the average number of days per year accounting for leap years.
constexpr double daysInYear{365.2425};

}

#endif
