/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_CONVERSION_CURRENCYSOURCE_HPP_
#define DRN_CONVERSION_CURRENCYSOURCE_HPP_

#include <QObject>

#include <conversion_export.h>
#include <foundation/QtMemory.hpp>


namespace pecunia
{

class FloatingPoint;

namespace currency
{

enum class Currency : quint16;

}}

namespace drn
{
namespace conversion
{

/**
 * @brief Provides an interface specification for the source currency conversions.
 */
struct DRN_CONVERSION_EXPORT CurrencySource : ::QObject
{
	Q_OBJECT

public:
	explicit CurrencySource(foundation::QtPtr<QObject> parent);
	/**
	 * @brief When implemented synchronously retrieves the conversion from one currency code to
	 * another.
	 *
	 * @param from The currency to convert from.
	 * @param to The currency to convert to.
	 *
	 * @return The ratio that when multiplied will take the value of "from" to the value of "to".
	 */
	virtual pecunia::FloatingPoint fetch(
		const pecunia::currency::Currency& from,
		const pecunia::currency::Currency& to
	) =0;
};

}}

inline drn::conversion::CurrencySource::CurrencySource(foundation::QtPtr<QObject> parent) :
	::QObject{parent.get()}
{}

#endif
