/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_DESKTOP_UI_CURRENCYCOMBOBOX_H_
#define DRN_DESKTOP_UI_CURRENCYCOMBOBOX_H_

#include <QComboBox>

#include <set>

#include <navigation/DisplayCurrency.h>

#include <desktop-ui_export.h>


class QWidget;

namespace pecunia::currency
{

enum class Currency : quint16;

}

namespace drn::foundation
{

template<typename>
class QtPtr;

}
namespace drn::desktop_ui
{

/**
 * @brief Displays an interface for selecting a currency.
 */
class DRN_DESKTOP_UI_EXPORT CurrencyComboBox : public ::QComboBox
{
	Q_OBJECT

	std::set<pecunia::currency::Currency> usableCodes_;
	navigation::CurrencyDisplayOptions displayAs_;

private:
	using ::QComboBox::addItem;
	using ::QComboBox::clear;
	using ::QComboBox::itemText;

public:
	explicit CurrencyComboBox(const foundation::QtPtr<::QWidget>& parent);
	/**
	 * @brief An accessor to the possible currencies that are selectable.
	 */
	[[nodiscard]]
	std::set<pecunia::currency::Currency> currencies() const noexcept;
	pecunia::currency::Currency currentCode() const;
	void setUsableCurrencies(
		const std::set<pecunia::currency::Currency>& usableCodes,
		const navigation::CurrencyDisplayOptions& displayAs
	);

public slots:
	void setCurrentCode(const pecunia::currency::Currency& code);
};

}

#endif
