/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_FOUNDATION_CALENDARTIME_H_
#define DRN_FOUNDATION_CALENDARTIME_H_

#include <QtCore>

#include <foundation_export.h>


class QDate;

namespace drn::foundation
{

/**
 * @brief Provides the first of the month for any given date.
 *
 * @param date The date to calculate the first of the month of.
 *
 * @return The first of the month from the given date, accounting for the month, etc.
 */
[[nodiscard]]
DRN_FOUNDATION_EXPORT ::QDate firstOfMonth(const ::QDate& date) noexcept;
/**
 * @brief Calculates the number of months between two dates.
 *
 * @param from The date from which to start calculating the number of months from.
 * @param to The date from which to end calculating the number of months.
 *
 * @return The number of months from (inclusive) to the supplied date (exclusive).
 */
[[nodiscard]]
DRN_FOUNDATION_EXPORT ::qint32 monthsBetween(const ::QDate& from, const ::QDate& to) noexcept;

}

#endif
