/*******************************************************************************
***  This file is part of Dux Rei Nummariae.                                 ***
***                                                                          ***
***  Copyright (C) 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024            ***
***  John Schneiderman <Licencing _AT_ Schneiderman _DOT_ me>                ***
***                                                                          ***
***  This program is free software: you can redistribute it and/or modify it ***
***  under the terms of the GNU Affero General Public License as published   ***
***  by the Free Software Foundation, either version 3 of the License, or    ***
***  (at your option) any later version.                                     ***
***                                                                          ***
***  This program is distributed in the hope that it will be useful, but     ***
***  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
***  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
***  See the GNU Affero General Public License for more details.             ***
***                                                                          ***
***  You should have received a copy of the GNU Affero General Public License***
***  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
*******************************************************************************/
#ifndef DRN_NAVIGATION_DISPLAYCURRENCY_H_
#define DRN_NAVIGATION_DISPLAYCURRENCY_H_

#include <array>
#include <cstdint>
#include <set>

#include <navigation_export.h>


class QString;

namespace pecunia::currency
{

enum class Currency : std::uint16_t;

}

namespace drn::navigation
{

/// @brief Provides the possible options for how a currency can be displayed.
enum class DRN_NAVIGATION_EXPORT CurrencyDisplayOptions
{
	IsoCode,
	Symbol,
	SymbolAndCode,
};

DRN_NAVIGATION_EXPORT ::QString toQString(const CurrencyDisplayOptions& displayAs);
DRN_NAVIGATION_EXPORT CurrencyDisplayOptions toCurrencyDisplayOptions(const ::QString& displayAs);
DRN_NAVIGATION_EXPORT::QString toDisplayable(
	const pecunia::currency::Currency& code,
	const CurrencyDisplayOptions displayAs
);
DRN_NAVIGATION_EXPORT pecunia::currency::Currency toCurrencyFromDisplayable(
	const ::QString& text,
	const std::set<pecunia::currency::Currency>& usableCodes,
	const CurrencyDisplayOptions displayAs
);
DRN_NAVIGATION_EXPORT ::QString presentationText(
	const navigation::CurrencyDisplayOptions& displayAs
);

inline constexpr std::array<CurrencyDisplayOptions, 3> allCurrencyDisplayOptions{{
	CurrencyDisplayOptions::IsoCode,
	CurrencyDisplayOptions::Symbol,
	CurrencyDisplayOptions::SymbolAndCode
}};

}

#endif
